.. _connectome_ref:

:mod:`nilearn.connectome`: Functional Connectivity
==================================================

.. automodule:: nilearn.connectome
   :no-members:
   :no-inherited-members:

Classes
-------

.. currentmodule:: nilearn.connectome

.. autosummary::
   :toctree: generated/
   :template: class.rst

   ConnectivityMeasure
   GroupSparseCovariance
   GroupSparseCovarianceCV

.. autoclasstree:: nilearn.connectome
   :full:

Functions
---------

.. currentmodule:: nilearn.connectome

.. autosummary::
   :toctree: generated/
   :template: function.rst

   sym_matrix_to_vec
   vec_to_sym_matrix
   group_sparse_covariance
   cov_to_corr
   prec_to_partial
